@@ -68,8 +68,13 @@ kernel_density <- function(
   if (!rlang::is_logical(quiet, n = 1))
     rlang::abort("`quiet` must be one of `TRUE` or `FALSE`")
 
+  # Replace name of geometry column in SF objects if necessary
+  grid <- set_geometry_name(grid)
+
   # Set bandwidth if not specified
-  if (rlang::is_null(bandwidth)) bandwidth <- set_bandwidth(data, quiet = quiet)
+  if (rlang::is_null(bandwidth)) {
+    bandwidth <- set_bandwidth(data, quiet = quiet, adjust = bandwidth_adjust)
+  }
 
   # Calculate KDE
   # Code for suppressing specific messages is from
@@ -81,6 +86,7 @@ kernel_density <- function(
           data,
           band_width = bandwidth * bandwidth_adjust,
           grid = grid,
+          quiet = quiet,
           ...
         )
       )
@@ -91,6 +97,7 @@ kernel_density <- function(
           band_width = bandwidth * bandwidth_adjust,
           weights = data[[weights]],
           grid = grid,
+          quiet = quiet,
           ...
         )
       )
